@@ -22,7 +22,7 @@ use Data::Context::Util qw/lol_path lol_iterate do_require/;
 use Class::Inspector;
 use Moose::Util::TypeConstraints qw/duck_type/;
 
-our $VERSION = version->new('0.1.10');
+our $VERSION = version->new('0.2.1');
 
 has path => (
     is       => 'rw',
@@ -39,6 +39,7 @@ has dc => (
     isa      => 'Data::Context',
     required => 1,
     weak_ref => 1,
+    handles => [qw/log/],
 );
 has raw => (
     is  => 'rw',
@@ -75,7 +76,13 @@ sub init {
 
     # get data actions
     my $count = 0;
-    lol_iterate( $raw, sub { $self->process_data(\$count, @_) } );
+    lol_iterate(
+        $raw,
+        sub {
+            my ($data, $path) = @_;
+            $self->process_data(\$count, $data, $path);
+        }
+    );
 
     return $self;
 }
@@ -112,13 +119,19 @@ sub get_data {
         my ($value, $replacer) = lol_path( $data, $path );
         my $module = $self->actions->{$path}{module};
         my $method = $self->actions->{$path}{method};
-        my $new = $module->$method( $value, $vars, $path, $self );
 
-        if ( blessed($new) && $new->isa('AnyEvent::CondVar') ) {
-            push @events, [ $replacer, $new ];
+        if ( $module->can($method) ) {
+            my $new = $module->$method( $value, $vars, $path, $self );
+
+            if ( blessed($new) && $new->isa('AnyEvent::CondVar') ) {
+                push @events, [ $replacer, $new ];
+            }
+            else {
+                $replacer->($new);
+            }
         }
         else {
-            $replacer->($new);
+            $self->log->error("Can't call $method on $module from config " . $self->path . '!');
         }
     }
 
@@ -131,6 +144,7 @@ sub get_data {
 
 sub process_data {
     my ( $self, $count, $data, $path ) = @_;
+    confess "No path supplied!" if ! defined $path;
 
     if ( !ref $data ) {
         if ( defined $data && $data =~ /^\# (.*) \#$/xms ) {
@@ -151,6 +165,9 @@ sub process_data {
             order  => $data->{ORDER},
             found  => $$count++,
         };
+        if ( ! defined $self->actions->{$path}{method} ) {
+            confess "Can't find method for '$path'!\n" . Dumper $data;
+        }
         do_require( $self->actions->{$path}{module} );
     }
 
@@ -188,7 +205,7 @@ Data::Context::Instance - The in memory instance of a data context config file
 
 =head1 VERSION
 
-This documentation refers to Data::Context::Instance version 0.1.10.
+This documentation refers to Data::Context::Instance version 0.2.1.
 
 =head1 SYNOPSIS
 
