@@ -17,7 +17,7 @@ use English qw/ -no_match_vars /;
 use Class::Inspector;
 use base qw/Exporter/;
 
-our $VERSION   = version->new('0.1.10');
+our $VERSION   = version->new('0.2.1');
 our @EXPORT_OK = qw/lol_path lol_iterate do_require/;
 
 sub lol_path {
@@ -26,11 +26,26 @@ sub lol_path {
     my $point = $lol;
     my $replacer;
 
+    if ( ! @path ) {
+        my $replacer = sub { confess "Can't replace '$path'!\n" };
+        if ( ref $lol eq 'HASH' ) {
+            $replacer = sub {
+                %$lol = %{ $_[0] };
+            };
+        }
+        elsif ( ref $lol eq 'ARRAY' ) {
+            $replacer = sub {
+                @$lol = @{ $_[0] };
+            };
+        }
+        return wantarray ? ( $lol, $replacer ) : $lol;
+    }
+
     POINT:
     while ( $point && @path ) {
 
         # ignore empty path parts
-        if ( ! defined $path[0] || $path[0] eq '' ) {
+        if ( $path[0] eq '' ) {
             shift @path;
             next POINT;
         }
@@ -70,7 +85,7 @@ sub lol_iterate {
     my $point = $lol;
 
     if ( !$path && defined $point ) {
-        $code->( $point, $path );
+        $code->( $point, '' );
     }
 
     $path = $path ? "$path." : '';
@@ -134,7 +149,7 @@ Data::Context::Util - Helper functions for Data::Context
 
 =head1 VERSION
 
-This documentation refers to Data::Context::Util version 0.1.10.
+This documentation refers to Data::Context::Util version 0.2.1.
 
 =head1 SYNOPSIS
 
